Install

$ pip install myPackageTFIMM

################

Usage

 from myPackageTFIMM import list_models, create_model

 list_models()
 model=create_model(dla34, 10)
 model.summary()

################

License

This project is licensed under the MIT License

################

Author
Alaa Elmor
